==> ionicons4-logo-googleplus-1.1.0.tgz: pkg/esm/hfc.js <==
/******/ // The require scope
/******/ var __wp_require__ = {};
/******/ 
/************************************************************************/
/******/ /* webpack/runtime/define property getters */
/******/ (() => {
/******/ 	// define getter functions for harmony exports
/******/ 	__wp_require__.d = (exports, definition) => {
/******/ 		for(var key in definition) {
/******/ 			if(__wp_require__.o(definition, key) && !__wp_require__.o(exports, key)) {
/******/ 				Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 			}
/******/ 		}
/******/ 	};
/******/ })();
/******/ 
/******/ /* webpack/runtime/hasOwnProperty shorthand */
/******/ (() => {
/******/ 	__wp_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ })();
/******/ 
/************************************************************************/
var __wp_exports__ = {};

// EXPORTS
__wp_require__.d(__wp_exports__, {
  "Z": () => (/* binding */ AwesomeHfc)
});

;// CONCATENATED MODULE: ./.hfc/propnames.js
/* harmony default export */ const propnames = ([["size","class","color"],[],[]]);
;// CONCATENATED MODULE: ./src/index.ts

const svgAttrs = [["xmlns","http://www.w3.org/2000/svg"],["x","0px"],["y","0px"],["viewBox","0 0 512 512"],["enable-background","new 0 0 512 512"],["space","preserve"]];
const svgHtml = "<g>    <path d=\"M318.2,230.9l-1.6-7l-156.6,0V288h90.7c-9.4,45-48.4,63.6-84.1,63.6c-26,0-50.2-7.8-68.3-25.3\t\tc-18.6-18.1-28.9-43.1-28.9-70.4c0-27.1,9.8-51.8,27.6-69.6c17.7-17.7,42-25.4,68.7-25.4c30.5,0,49.9,13.8,58.1,21.1l48-47.7\t\tC258.3,122.6,221.5,93,164.1,93c0,0,0,0,0,0c-44.3,0-86.7,16.8-117.7,47.8C15.9,171.3,0,215.2,0,256s15,82.6,44.6,113.3\t\tC76.3,402,121.2,419,167.5,419c42.1,0,81.9-16.5,110.3-46.3c28-29.4,42.4-70.1,42.4-112.7C320.1,242,318.3,231.3,318.2,230.9z\"></path>    <polygon points=\"512,224 455,224 455,167 414,167 414,224 357,224 357,265 414,265 414,322 455,322 455,265 512,265 \t\"></polygon>  </g>";
class AwesomeHfc {
    constructor(container, props) {
        this.container = container;
        for (let i = 0; i < svgAttrs.length; i++) {
            container.setAttribute(svgAttrs[i][0], svgAttrs[i][1]);
        }
        this.render(props);
        container.innerHTML = svgHtml;
    }
    changed(props) {
        this.render(props);
    }
    disconnected() { }
    render(props) {
        if (props.attrs.size) {
            this.container.setAttribute("width", props.attrs.size);
            this.container.setAttribute("height", props.attrs.size);
        }
        if (props.attrs.class) {
            this.container.setAttributeNS(null, "class", props.attrs.class);
        }
        if (props.attrs.color) {
            this.container.style.fill = props.attrs.color;
            this.container.style.color = props.attrs.color;
        }
        bindToElement(this.container, props.others);
    }
}
AwesomeHfc.tag = "svg";
AwesomeHfc.props = propnames;
function bindToElement(elem, obj) {
    for (let i = 0, keys = Object.keys(obj); i < keys.length; i++) {
        const key = keys[i];
        const value = obj[key];
        if (key === "style") {
            if (typeof value === "object") {
                Object.assign(elem.style, value);
            }
            else {
                elem.style.cssText += value;
            }
            continue;
        }
        if (typeof value === "function") {
            elem[key] = function (event) {
                value(event);
            };
        }
        else {
            elem.setAttribute(key, value);
        }
    }
}

var __wp_exports__default = __wp_exports__.Z;
export { __wp_exports__default as default };

==> ionicons4-logo-googleplus-1.3.0.tgz: pkg/esm/hfc.js <==
/******/ // The require scope
/******/ var __wp_require__ = {};
/******/ 
/************************************************************************/
/******/ /* webpack/runtime/define property getters */
/******/ (() => {
/******/ 	// define getter functions for harmony exports
/******/ 	__wp_require__.d = (exports, definition) => {
/******/ 		for(var key in definition) {
/******/ 			if(__wp_require__.o(definition, key) && !__wp_require__.o(exports, key)) {
/******/ 				Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 			}
/******/ 		}
/******/ 	};
/******/ })();
/******/ 
/******/ /* webpack/runtime/hasOwnProperty shorthand */
/******/ (() => {
/******/ 	__wp_require__.o = (obj, prop) => (Object.prototype.hasOwnProperty.call(obj, prop))
/******/ })();
/******/ 
/************************************************************************/
var __wp_exports__ = {};

// EXPORTS
__wp_require__.d(__wp_exports__, {
  "Z": () => (/* binding */ AwesomeHfc)
});

;// CONCATENATED MODULE: ./.hfc/propnames.js
/* harmony default export */ const propnames = ([["size","class","color"],[],[]]);

;// CONCATENATED MODULE: ./src/index.ts

const svgAttrs = [["xmlns","http://www.w3.org/2000/svg"],["x","0px"],["y","0px"],["viewBox","0 0 512 512"],["enable-background","new 0 0 512 512"],["space","preserve"]];
const svgHtml = "<g>    <path d=\"M318.2,230.9l-1.6-7l-156.6,0V288h90.7c-9.4,45-48.4,63.6-84.1,63.6c-26,0-50.2-7.8-68.3-25.3c-18.6-18.1-28.9-43.1-28.9-70.4c0-27.1,9.8-51.8,27.6-69.6c17.7-17.7,42-25.4,68.7-25.4c30.5,0,49.9,13.8,58.1,21.1l48-47.7C258.3,122.6,221.5,93,164.1,93c0,0,0,0,0,0c-44.3,0-86.7,16.8-117.7,47.8C15.9,171.3,0,215.2,0,256s15,82.6,44.6,113.3C76.3,402,121.2,419,167.5,419c42.1,0,81.9-16.5,110.3-46.3c28-29.4,42.4-70.1,42.4-112.7C320.1,242,318.3,231.3,318.2,230.9z\"></path>    <polygon points=\"512,224 455,224 455,167 414,167 414,224 357,224 357,265 414,265 414,322 455,322 455,265 512,265 \"></polygon>  </g>";
class AwesomeHfc {
    constructor(container, props) {
        this.container = container;
        for (let i = 0; i < svgAttrs.length; i++) {
            container.setAttribute(svgAttrs[i][0], svgAttrs[i][1]);
        }
        this.render(props);
        container.innerHTML = svgHtml;
    }
    changed(props) {
        this.render(props);
    }
    disconnected() { }
    render(props) {
        if (props.attrs.size) {
            this.container.setAttribute("width", props.attrs.size);
            this.container.setAttribute("height", props.attrs.size);
        }
        if (props.attrs.class) {
            this.container.setAttributeNS(null, "class", props.attrs.class);
        }
        if (props.attrs.color) {
            this.container.style.fill = props.attrs.color;
            this.container.style.color = props.attrs.color;
        }
        bindToElement(this.container, props.others);
    }
}
AwesomeHfc.tag = "svg";
AwesomeHfc.props = propnames;
function bindToElement(elem, obj) {
    for (let i = 0, keys = Object.keys(obj); i < keys.length; i++) {
        const key = keys[i];
        const value = obj[key];
        if (key === "style") {
            if (typeof value === "object") {
                Object.assign(elem.style, value);
            }
            else {
                elem.style.cssText += value;
            }
            continue;
        }
        if (typeof value === "function") {
            elem[key] = function (event) {
                value(event);
            };
        }
        else {
            elem.setAttribute(key, value);
        }
    }
}

var __wp_exports__default = __wp_exports__.Z;
export { __wp_exports__default as default };
